myimagelib.pivLib.compact\_PIV
==============================

.. currentmodule:: myimagelib.pivLib

.. autoclass:: compact_PIV

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~compact_PIV.__init__
      ~compact_PIV.get_frame
      ~compact_PIV.get_labels
      ~compact_PIV.to_mat
   
   

   
   
   